==> savane-1.0.7+4.tar.gz: savane-1.0.7+4/frontend/php/admin/groupedit-add.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: groupedit-add.php,v 1.15 2005/06/22 19:18:05 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#
#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "../include/pre.php";
require  $GLOBALS['sys_www_topdir']."/include/account.php";

site_admin_header(array('title'=>_("Group Add"),'toptab'=>'admgroup'));

# ########################################################

if ($Submit) {
	# check for valid group name
	if (!account_groupnamevalid($form_unixgrp)) {
		exit_error("Invalid Group Name",$register_error);
	}	

	if ($group_idname) {
	$newid = db_insertid(db_query("INSERT INTO groups (group_name,is_public,unix_group_name,status,type,register_time) VALUES "
		. "('$group_idname',$form_public,'$form_unixgrp'"
		. ",'$form_status','$group_type', ".time().")")); 
	} 
	session_redirect($GLOBALS['sys_home']."admin/groupedit.php?group_id=$newid");
} 

# FIXME: non conform to the coding style
?>

<form action="groupedit-add.php" method="post">
<p>New descriptive group name:
<br /><input type="text" name="group_idname">
<p>New system group name:
<br /><input type="text" name="form_unixgrp">
<br />Status
<SELECT name="form_status">
<OPTION value="A">Active
<OPTION value="P">Pending
<OPTION value="H">Holding
<OPTION value="D">Deleted
</SELECT>
<br />Public?
<SELECT name="form_public">
<OPTION value="1">Yes
<OPTION value="0">No
</SELECT>

<?php
# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: groupedit-add.php,v 1.15 2005/06/22 19:18:05 yeupou Exp $
#
echo '<BR>Group Type';
# we get site-specific content
utils_get_content("admin/groupedit_grouptype");
echo show_group_type_box('group_type',$row_grp['type']);
?>
<br /><input type="submit" name="Submit" value="Submit">
</form>

<?php
# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: groupedit-add.php,v 1.15 2005/06/22 19:18:05 yeupou Exp $
#
site_admin_footer(array());

?>

==> savane-1.0.8+2.tar.gz: savane-1.0.8+2/frontend/php/admin/groupedit-add.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: groupedit-add.php,v 1.16 2005/06/30 17:19:33 toddy Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#
#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

require "../include/pre.php";
require  $GLOBALS['sys_www_topdir']."/include/account.php";

site_admin_header(array('title'=>_("Group Add"),'toptab'=>'admgroup'));

# ########################################################

if ($Submit) {
	# check for valid group name
	if (!account_groupnamevalid($form_unixgrp)) {
		exit_error("Invalid Group Name",$register_error);
	}	

	if ($group_idname) {
	$newid = db_insertid(db_query("INSERT INTO groups (group_name,is_public,unix_group_name,status,type,register_time) VALUES "
		. "('$group_idname',$form_public,'$form_unixgrp'"
		. ",'$form_status','$group_type', ".time().")")); 
	} 
	session_redirect($GLOBALS['sys_home']."admin/groupedit.php?group_id=$newid");
} 

# FIXME: non conform to the coding style
?>

<form action="groupedit-add.php" method="post">
<p>New descriptive group name:
<br /><input type="text" name="group_idname">
<p>New system group name:
<br /><input type="text" name="form_unixgrp">
<br />Status
<SELECT name="form_status">
<OPTION value="A">Active
<OPTION value="P">Pending
<OPTION value="H">Holding
<OPTION value="D">Deleted
</SELECT>
<br />Public?
<SELECT name="form_public">
<OPTION value="1">Yes
<OPTION value="0">No
</SELECT>

<?php
# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: groupedit-add.php,v 1.16 2005/06/30 17:19:33 toddy Exp $
#
echo '<BR>Group Type';
# we get site-specific content
utils_get_content("admin/groupedit_grouptype");
echo show_group_type_box('group_type',$row_grp['type']);
?>
<br /><input type="submit" name="Submit" value="Submit">
</form>

<?php
# This file is part of the Savane project
# <http:#gna.org/projects/savane/>
#
# $Id: groupedit-add.php,v 1.16 2005/06/30 17:19:33 toddy Exp $
#
site_admin_footer(array());

?>
